__version__ = "0.6.25"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(detached from v0.6.25)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'b67785dabc60e413a396f6d8a664afc89e1a0d6b'
__git_head_subject__ = 'Finished release v0.6.25.'
__git_head_message__ = '* release/v0.6.25:\n  gitignore\n  buildout.cfg: changed isolated python version to v2.7.6.20\n  buildout.cfg: changed isolated python version to v2.7.6.19'
__git_dirty_diff__ = ''